# Parameters

```{eval-rst}
.. autoclass:: openpkpd.model.parameters.ThetaSpec
   :members:
   :undoc-members: False
```

```{eval-rst}
.. autoclass:: openpkpd.model.parameters.OmegaSpec
   :members:
   :undoc-members: False
```

```{eval-rst}
.. autoclass:: openpkpd.model.parameters.SigmaSpec
   :members:
   :undoc-members: False
```

```{eval-rst}
.. autoclass:: openpkpd.model.parameters.ParameterSet
   :members:
   :undoc-members: False
```
